@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef SIEVEPREVIEWGENERATEDCODEWIDGETTEST_H
-#define SIEVEPREVIEWGENERATEDCODEWIDGETTEST_H
+#pragma once
 
 #include <QObject>
 
@@ -19,4 +18,3 @@ private Q_SLOTS:
     void shouldHaveDefaultValues();
 };
 
-#endif // SIEVEPREVIEWGENERATEDCODEWIDGETTEST_H
