@@ -1,10 +1,9 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
-#ifndef SELECTMATCHTYPECOMBOBOX_H
-#define SELECTMATCHTYPECOMBOBOX_H
+#pragma once
 
 #include <QComboBox>
 
@@ -33,4 +32,3 @@ private:
 };
 }
 
-#endif // SELECTMATCHTYPECOMBOBOX_H
