@@ -1,10 +1,9 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
-#ifndef SIEVEACTIONREPLACE_H
-#define SIEVEACTIONREPLACE_H
+#pragma once
 
 #include "sieveaction.h"
 
@@ -26,4 +25,3 @@ public:
 };
 }
 
-#endif // SIEVEACTIONREPLACE_H
