@@ -1,10 +1,9 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
-#ifndef SIEVEACTIONSETFLAGS_H
-#define SIEVEACTIONSETFLAGS_H
+#pragma once
 
 #include "sieveactionabstractflags.h"
 namespace KSieveUi
@@ -20,4 +19,3 @@ public:
 };
 }
 
-#endif // SIEVEACTIONSETFLAGS_H
