@@ -1,10 +1,9 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
-#ifndef SIEVEACTIONSTOP_H
-#define SIEVEACTIONSTOP_H
+#pragma once
 
 #include "sieveaction.h"
 
@@ -21,4 +20,3 @@ public:
 };
 }
 
-#endif // SIEVEACTIONSTOP_H
