@@ -1,10 +1,9 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
-#ifndef SIEVEACTIONVACATION_H
-#define SIEVEACTIONVACATION_H
+#pragma once
 
 #include "sieveaction.h"
 namespace KSieveUi
@@ -29,4 +28,3 @@ private:
 };
 }
 
-#endif // SIEVEACTIONVACATION_H
