@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef SIEVEACTIONWIDGETLISTER_H
-#define SIEVEACTIONWIDGETLISTER_H
+#pragma once
 
 #include "sieveglobalvariablewidget.h"
 #include <Libkdepim/KWidgetLister>
@@ -91,4 +90,3 @@ private:
 };
 }
 
-#endif // SIEVEACTIONWIDGETLISTER_H
