@@ -1,10 +1,9 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
-#ifndef SELECTADDRESSPARTCOMBOBOX_H
-#define SELECTADDRESSPARTCOMBOBOX_H
+#pragma once
 
 #include <QComboBox>
 
@@ -32,4 +31,3 @@ private:
 };
 }
 
-#endif // SELECTADDRESSPARTCOMBOBOX_H
