@@ -1,10 +1,9 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
-#ifndef SELECTBODYTYPEWIDGET_H
-#define SELECTBODYTYPEWIDGET_H
+#pragma once
 
 #include <QWidget>
 
@@ -34,4 +33,3 @@ private:
 };
 }
 
-#endif // SELECTBODYTYPEWIDGET_H
