@@ -1,10 +1,9 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
-#ifndef SELECTSIZETYPECOMBOBOX_H
-#define SELECTSIZETYPECOMBOBOX_H
+#pragma once
 
 #include <QComboBox>
 
@@ -28,4 +27,3 @@ private:
 };
 }
 
-#endif // SELECTSIZETYPECOMBOBOX_H
