@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -40,9 +40,7 @@ SieveScriptListItem::SieveScriptListItem(const QString &text, QListWidget *paren
 {
 }
 
-SieveScriptListItem::~SieveScriptListItem()
-{
-}
+SieveScriptListItem::~SieveScriptListItem() = default;
 
 void SieveScriptListItem::setDescription(const QString &desc)
 {
@@ -182,9 +180,7 @@ SieveScriptListBox::SieveScriptListBox(const QString &title, QWidget *parent)
     updateButtons();
 }
 
-SieveScriptListBox::~SieveScriptListBox()
-{
-}
+SieveScriptListBox::~SieveScriptListBox() = default;
 
 void SieveScriptListBox::slotCustomMenuRequested(const QPoint &pos)
 {
@@ -425,7 +421,11 @@ void SieveScriptListBox::loadBlock(QXmlStreamReader &n, SieveScriptPage *current
     bool hasCreatedAIfBlock = false;
     bool previousElementWasAComment = false;
     while (n.readNextStartElement()) {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         const QStringRef tagName = n.name();
+#else
+        const QStringView tagName = n.name();
+#endif
         // qDebug() <<"SieveScriptListBox::loadBlock tagName " << tagName;
         if (tagName == QLatin1String("control")) {
             previousElementWasAComment = false;
