@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef SIEVESCRIPTTABWIDGET_H
-#define SIEVESCRIPTTABWIDGET_H
+#pragma once
 
 #include <QTabWidget>
 
@@ -23,4 +22,3 @@ private Q_SLOTS:
 };
 }
 
-#endif // SIEVESCRIPTTABWIDGET_H
