@@ -1,11 +1,10 @@
 /*
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
 
-#ifndef SIEVEEDITORMENUBAR_H
-#define SIEVEEDITORMENUBAR_H
+#pragma once
 
 #include <QMenuBar>
 
@@ -108,4 +107,3 @@ private:
 };
 }
 
-#endif // SIEVEEDITORMENUBAR_H
