@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2018-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2018-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef SIEVEPURPOSEMENUWIDGET_H
-#define SIEVEPURPOSEMENUWIDGET_H
+#pragma once
 
 #include <PimCommon/PurposeMenuWidget>
 namespace KSieveUi
@@ -26,4 +25,3 @@ private:
 };
 }
 
-#endif // SIEVEPURPOSEMENUWIDGET_H
