@@ -1,4 +1,4 @@
-/* SPDX-FileCopyrightText: 2011-2021 Laurent Montel <montel@kde.org>
+/* SPDX-FileCopyrightText: 2011-2022 Laurent Montel <montel@kde.org>
  *
  * SPDX-License-Identifier: LGPL-2.0-or-later
  */
@@ -31,9 +31,7 @@ using namespace KSieveUi;
 class KSieveUi::SieveTextEditPrivate
 {
 public:
-    SieveTextEditPrivate()
-    {
-    }
+    SieveTextEditPrivate() = default;
 
     SieveLineNumberArea *m_sieveLineNumberArea = nullptr;
     KPIMTextEdit::TextEditorCompleter *mTextEditorCompleter = nullptr;
@@ -308,7 +306,7 @@ void SieveTextEdit::addExtraMenuEntry(QMenu *menu, QPoint pos)
     }
 }
 
-QString SieveTextEdit::selectedWord(const QPoint &pos) const
+QString SieveTextEdit::selectedWord(QPoint pos) const
 {
     QTextCursor wordSelectCursor(pos.isNull() ? textCursor() : cursorForPosition(pos));
     wordSelectCursor.clearSelection();
