@@ -1,12 +1,12 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
 
 #include "sievetexteditwidget.h"
-#include <QVBoxLayout>
 #include "editor/sievetextedit.h"
+#include <QVBoxLayout>
 
 #include <KPIMTextEdit/PlainTextEditFindBar>
 #include <KPIMTextEdit/SlideContainer>
@@ -15,9 +15,7 @@ using namespace KSieveUi;
 class KSieveUi::SieveTextEditWidgetPrivate
 {
 public:
-    SieveTextEditWidgetPrivate()
-    {
-    }
+    SieveTextEditWidgetPrivate() = default;
 
     KSieveUi::SieveTextEdit *mTextEdit = nullptr;
     KPIMTextEdit::SlideContainer *mSliderContainer = nullptr;
@@ -38,14 +36,11 @@ SieveTextEditWidget::SieveTextEditWidget(QWidget *parent)
     initialize();
 }
 
-SieveTextEditWidget::~SieveTextEditWidget()
-{
-    delete d;
-}
+SieveTextEditWidget::~SieveTextEditWidget() = default;
 
 void SieveTextEditWidget::initialize(KSieveUi::SieveTextEdit *custom)
 {
-    auto *mainLayout = new QVBoxLayout(this);
+    auto mainLayout = new QVBoxLayout(this);
     mainLayout->setContentsMargins({});
     if (custom) {
         d->mTextEdit = custom;
