@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -9,7 +9,6 @@
 #include <KLocalizedString>
 #include <QAction>
 
-#include <QPointer>
 
 using namespace KSieveUi;
 
@@ -48,9 +47,7 @@ SieveEditorParsingMissingFeatureWarning::SieveEditorParsingMissingFeatureWarning
     setWordWrap(true);
 }
 
-SieveEditorParsingMissingFeatureWarning::~SieveEditorParsingMissingFeatureWarning()
-{
-}
+SieveEditorParsingMissingFeatureWarning::~SieveEditorParsingMissingFeatureWarning() = default;
 
 QString SieveEditorParsingMissingFeatureWarning::initialScript() const
 {
@@ -60,10 +57,9 @@ QString SieveEditorParsingMissingFeatureWarning::initialScript() const
 void SieveEditorParsingMissingFeatureWarning::slotShowDetails(const QString &content)
 {
     if (content == QLatin1String("sieveerrordetails")) {
-        QPointer<SieveScriptParsingErrorDialog> dlg = new SieveScriptParsingErrorDialog(this);
-        dlg->setError(mScript, mErrors);
-        dlg->exec();
-        delete dlg;
+        SieveScriptParsingErrorDialog dlg(this);
+        dlg.setError(mScript, mErrors);
+        dlg.exec();
     }
 }
 
