@@ -1,5 +1,5 @@
 /* SPDX-FileCopyrightText: 2010 Torgny Nyblom <nyblom@kde.org>
- * SPDX-FileCopyrightText: 2010-2021 Laurent Montel <montel@kde.org>
+ * SPDX-FileCopyrightText: 2010-2022 Laurent Montel <montel@kde.org>
  *
  * SPDX-License-Identifier: LGPL-2.0-or-later
  */
@@ -92,9 +92,7 @@ FindBarBase::FindBarBase(QWidget *parent)
     hide();
 }
 
-FindBarBase::~FindBarBase()
-{
-}
+FindBarBase::~FindBarBase() = default;
 
 QMenu *FindBarBase::optionsMenu()
 {
@@ -146,9 +144,9 @@ void FindBarBase::setFoundMatch(bool match)
     if (!mSearch->text().isEmpty()) {
         if (mNegativeBackground.isEmpty()) {
             KStatefulBrush bgBrush(KColorScheme::View, KColorScheme::PositiveBackground);
-            mPositiveBackground = QStringLiteral("QLineEdit{ background-color:%1 }").arg(bgBrush.brush(mSearch).color().name());
+            mPositiveBackground = QStringLiteral("QLineEdit{ background-color:%1 }").arg(bgBrush.brush(mSearch->palette()).color().name());
             bgBrush = KStatefulBrush(KColorScheme::View, KColorScheme::NegativeBackground);
-            mNegativeBackground = QStringLiteral("QLineEdit{ background-color:%1 }").arg(bgBrush.brush(mSearch).color().name());
+            mNegativeBackground = QStringLiteral("QLineEdit{ background-color:%1 }").arg(bgBrush.brush(mSearch->palette()).color().name());
         }
         if (match) {
             styleSheet = mPositiveBackground;
