@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -13,7 +13,7 @@ class RenameScriptJobTest : public QObject
     Q_OBJECT
 public:
     explicit RenameScriptJobTest(QObject *parent = nullptr);
-    ~RenameScriptJobTest();
+    ~RenameScriptJobTest() override;
 
 private Q_SLOTS:
     void canNotStartByDefault();
