@@ -4,9 +4,7 @@
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef XMLPRINTINGSCRIPTBUILDERTEST_H
-#define XMLPRINTINGSCRIPTBUILDERTEST_H
-
+#pragma once
 #include <QObject>
 
 class XMLPrintingScriptBuilderTest : public QObject
@@ -19,5 +17,3 @@ private Q_SLOTS:
     void shouldCreateXml_data();
     void shouldCreateXml();
 };
-
-#endif // XMLPRINTINGSCRIPTBUILDERTEST_H
