@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef SIEVEIMAPINSTANCEINTERFACEMANAGER_H
-#define SIEVEIMAPINSTANCEINTERFACEMANAGER_H
+#pragma once
 
 #include "ksieveui_export.h"
 #include <QObject>
@@ -33,4 +32,3 @@ private:
 };
 }
 
-#endif // SIEVEIMAPINSTANCEINTERFACEMANAGER_H
