@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -13,7 +13,7 @@ class SieveScriptDebuggerWarningTest : public QObject
     Q_OBJECT
 public:
     explicit SieveScriptDebuggerWarningTest(QObject *parent = nullptr);
-    ~SieveScriptDebuggerWarningTest();
+    ~SieveScriptDebuggerWarningTest() override;
 
 private Q_SLOTS:
     void shouldHaveDefaultValue();
