@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -14,9 +14,7 @@ SieveScriptDebuggerWidgetTest::SieveScriptDebuggerWidgetTest(QObject *parent)
 {
 }
 
-SieveScriptDebuggerWidgetTest::~SieveScriptDebuggerWidgetTest()
-{
-}
+SieveScriptDebuggerWidgetTest::~SieveScriptDebuggerWidgetTest() = default;
 
 void SieveScriptDebuggerWidgetTest::shouldHaveDefaultValue()
 {
@@ -27,8 +25,8 @@ void SieveScriptDebuggerWidgetTest::shouldHaveDefaultValue()
     const int numberOfStackWidget(2);
     QCOMPARE(stackedwidget->count(), numberOfStackWidget);
     for (int i = 0; i < numberOfStackWidget; ++i) {
-        QWidget *w = stackedwidget->widget(i);
-        QVERIFY((w->objectName() == QLatin1String("sievescriptfrontend")) || (w->objectName() == QLatin1String("sievenoexistingfrontend")));
+        QWidget *widget = stackedwidget->widget(i);
+        QVERIFY((widget->objectName() == QLatin1String("sievescriptfrontend")) || (widget->objectName() == QLatin1String("sievenoexistingfrontend")));
     }
 }
 
