@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef SIEVESCRIPTDEBUGGERDIALOG_H
-#define SIEVESCRIPTDEBUGGERDIALOG_H
+#pragma once
 
 #include "ksieveui_private_export.h"
 #include <QDialog>
@@ -38,4 +37,3 @@ private:
 };
 }
 
-#endif // SIEVESCRIPTDEBUGGERDIALOG_H
