@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef SIEVEDEFAULTTEMPLATE_H
-#define SIEVEDEFAULTTEMPLATE_H
+#pragma once
 
 #include "sievetemplatewidget.h"
 
@@ -17,4 +16,3 @@ Q_REQUIRED_RESULT QVector<PimCommon::defaultTemplate> defaultTemplates();
 }
 }
 
-#endif // SIEVEDEFAULTTEMPLATE_H
