@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -14,9 +14,7 @@ SieveAccountTest::SieveAccountTest(QObject *parent)
 {
 }
 
-SieveAccountTest::~SieveAccountTest()
-{
-}
+SieveAccountTest::~SieveAccountTest() = default;
 
 void SieveAccountTest::shouldHaveDefaultValue()
 {
@@ -92,7 +90,7 @@ void SieveAccountTest::shouldCreateIdentifier()
     account.setServerName(servername);
     account.setUserName(username);
 
-    //Identifier doesn't depend against theses settings
+    // Identifier doesn't depend on these settings
     KSieveUi::SieveImapAccountSettings::AuthenticationMode type = KSieveUi::SieveImapAccountSettings::DigestMD5;
     KSieveUi::SieveImapAccountSettings::EncryptionMode mode = KSieveUi::SieveImapAccountSettings::SSLorTLS;
     account.setPort(42);
