@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef VACATIONEDITWIDGET_H
-#define VACATIONEDITWIDGET_H
+#pragma once
 
 #include "vacationutils.h"
 #include <QWidget>
@@ -136,4 +135,3 @@ protected:
 };
 }
 
-#endif // VACATIONEDITWIDGET_H
