@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef INCLUDEFILELINEEDIT_H
-#define INCLUDEFILELINEEDIT_H
+#pragma once
 
 #include "ksieveui_private_export.h"
 #include "lineeditvalidator.h"
@@ -27,4 +26,3 @@ private:
     QStringListModel *mStringListModel = nullptr;
 };
 }
-#endif // INCLUDEFILELINEEDIT_H
